Struct ate::crypto::encrypt_key::EncryptResult
source · [−]pub struct EncryptResult {
pub iv: InitializationVector,
pub data: Vec<u8, Global>,
}Fields
iv: InitializationVectordata: Vec<u8, Global>Trait Implementations
sourceimpl Clone for EncryptResult
impl Clone for EncryptResult
sourcefn clone(&self) -> EncryptResult
fn clone(&self) -> EncryptResult
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for EncryptResult
impl Debug for EncryptResult
sourceimpl<'de> Deserialize<'de> for EncryptResult
impl<'de> Deserialize<'de> for EncryptResult
sourcefn deserialize<__D>(
__deserializer: __D
) -> Result<EncryptResult, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D
) -> Result<EncryptResult, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Hash for EncryptResult
impl Hash for EncryptResult
sourceimpl Ord for EncryptResult
impl Ord for EncryptResult
sourcefn cmp(&self, other: &EncryptResult) -> Ordering
fn cmp(&self, other: &EncryptResult) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<EncryptResult> for EncryptResult
impl PartialEq<EncryptResult> for EncryptResult
sourcefn eq(&self, other: &EncryptResult) -> bool
fn eq(&self, other: &EncryptResult) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &EncryptResult) -> bool
fn ne(&self, other: &EncryptResult) -> bool
This method tests for !=.
sourceimpl PartialOrd<EncryptResult> for EncryptResult
impl PartialOrd<EncryptResult> for EncryptResult
sourcefn partial_cmp(&self, other: &EncryptResult) -> Option<Ordering>
fn partial_cmp(&self, other: &EncryptResult) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl Serialize for EncryptResult
impl Serialize for EncryptResult
sourcefn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for EncryptResult
impl StructuralEq for EncryptResult
impl StructuralPartialEq for EncryptResult