#[repr(u8)]
pub enum KeySize {
Bit128,
Bit192,
Bit256,
}Expand description
Size of a cryptographic key, smaller keys are still very secure but have less room in the future should new attacks be found against the crypto algorithms used by ATE.
Variants
Bit128
Bit192
Bit256
Implementations