Public key which is one side of a private key. Public keys allow records/events stored within the ATE redo log to have integrity without actually being able to read the records themselves. This attribute allows a chain-of-trust to be built without access to the data held within of chain. Asymetric crypto in ATE uses the leading candidates from NIST that provide protection against quantom computer attacks
Variants
Falcon512
Falcon1024
Implementations