pub enum EdnsOption {
DAU(SupportedAlgorithms),
DHU(SupportedAlgorithms),
N3U(SupportedAlgorithms),
Unknown(u16, Vec<u8, Global>),
}Expand description
options used to pass information about capabilities between client and server
note: Not all EdnsOptions are supported at this time.
http://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-13
Variants
DAU(SupportedAlgorithms)
DHU(SupportedAlgorithms)
N3U(SupportedAlgorithms)
Unknown(u16, Vec<u8, Global>)
Unknown, used to deal with unknown or unsupported codes
Implementations