pub struct Label(_);Expand description
Labels are always stored as ASCII, unicode characters must be encoded with punycode
Implementations
sourceimpl Label
impl Label
sourcepub fn from_raw_bytes(bytes: &[u8]) -> Result<Label, ProtoError>
pub fn from_raw_bytes(bytes: &[u8]) -> Result<Label, ProtoError>
These must only be ASCII, with unicode encoded to PunyCode, or other such transformation.
This uses the bytes as raw ascii values, with nothing escaped on the wire.
Generally users should use from_str or from_ascii
sourcepub fn from_utf8(s: &str) -> Result<Label, ProtoError>
pub fn from_utf8(s: &str) -> Result<Label, ProtoError>
Translates this string into IDNA safe name, encoding to punycode as necessary.
sourcepub fn from_ascii(s: &str) -> Result<Label, ProtoError>
pub fn from_ascii(s: &str) -> Result<Label, ProtoError>
Takes the ascii string and returns a new label.
This will return an Error if the label is not an ascii string
sourcepub fn to_lowercase(&self) -> Label
pub fn to_lowercase(&self) -> Label
Converts this label to lowercase
sourcepub fn is_wildcard(&self) -> bool
pub fn is_wildcard(&self) -> bool
Returns true if this label is the wildcard, ‘*’, label
sourcepub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
pub fn as_bytes(&self) -> &[u8]ⓘNotable traits for &[u8]impl Read for &[u8]impl Write for &mut [u8]
Returns the raw bytes of the label, this is good for writing to the wire.
See Display for presentation version (unescaped from punycode, etc)
sourcepub fn eq_ignore_ascii_case(&self, other: &Label) -> bool
pub fn eq_ignore_ascii_case(&self, other: &Label) -> bool
Performs the equivalence operation disregarding case
sourcepub fn cmp_with_f<F>(&self, other: &Label) -> Ordering where
F: LabelCmp,
pub fn cmp_with_f<F>(&self, other: &Label) -> Ordering where
F: LabelCmp,
compares with the other label, ignoring case
sourcepub fn to_utf8(&self) -> String
pub fn to_utf8(&self) -> String
Performs the conversion to utf8 from IDNA as necessary, see fmt for more details