pub struct SinkError(pub SinkErrorKind, _);Expand description
The Error type.
This tuple struct is made of two elements:
- an
ErrorKindwhich is used to determine the type of the error. - An internal
State, not meant for direct use outside oferror_chaininternals, containing:- a backtrace, generated when the error is created.
- an error chain, used for the implementation of
Error::cause().
Tuple Fields
0: SinkErrorKindThe kind of the error.
Implementations
sourceimpl SinkError
impl SinkError
sourcepub fn from_kind(kind: SinkErrorKind) -> SinkError
pub fn from_kind(kind: SinkErrorKind) -> SinkError
Constructs an error from a kind, and generates a backtrace.
sourcepub fn with_chain<E, K>(error: E, kind: K) -> SinkError where
E: Error + Send + 'static,
K: Into<SinkErrorKind>,
pub fn with_chain<E, K>(error: E, kind: K) -> SinkError where
E: Error + Send + 'static,
K: Into<SinkErrorKind>,
Constructs a chained error from another error and a kind, and generates a backtrace.
sourcepub fn with_boxed_chain<K>(error: Box<dyn Error + Send>, kind: K) -> SinkError where
K: Into<SinkErrorKind>,
pub fn with_boxed_chain<K>(error: Box<dyn Error + Send>, kind: K) -> SinkError where
K: Into<SinkErrorKind>,
Construct a chained error from another boxed error and a kind, and generates a backtrace
sourcepub fn kind(&self) -> &SinkErrorKind
pub fn kind(&self) -> &SinkErrorKind
Returns the kind of the error.
sourcepub fn backtrace(&self) -> Option<&Backtrace>
pub fn backtrace(&self) -> Option<&Backtrace>
Returns the backtrace associated with this error.
sourcepub fn chain_err<F, EK>(self, error: F) -> SinkError where
F: FnOnce() -> EK,
EK: Into<SinkErrorKind>,
pub fn chain_err<F, EK>(self, error: F) -> SinkError where
F: FnOnce() -> EK,
EK: Into<SinkErrorKind>,
Extends the error chain with a new entry.
sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A short description of the error.
This method is identical to Error::description()