Enum ate::prelude::ReadOption
source · [−]pub enum ReadOption {
Inherit,
Everyone(Option<EncryptKey>),
Specific(AteHash, DerivedEncryptKey),
}Expand description
Determines if the event record will be restricted so that only a specific set of users can read the data. If it is limited to a specific set of users they must all possess the encryption key in their session when accessing these data records of which the hash of the encryption key must match this record.
Variants
Inherit
Everyone(Option<EncryptKey>)
Specific(AteHash, DerivedEncryptKey)
Implementations
sourceimpl ReadOption
impl ReadOption
pub fn from_key(key: &EncryptKey) -> ReadOption