pub struct Dao<D> { /* private fields */ }
Represents a data object that will be represented as one or more events on the redo-log and validated in the chain-of-trust.

Reading this object using none-mutable behavior will incur no IO on the redo-log however if you edit the object you must commit it to the Dio before it goes out of scope or the data will be lost (in Debug mode this will even trigger an assert).

Metadata about the data object can also be accessed via this object which allows you to read access rights, etc.

If you wish to actually modify the data you must first call the ‘mut’ function on an open transaction, which will give you an object you can modify

Implementations