pub struct ChainSingleUser<'a> { /* private fields */ }
Represents an exclusive lock on a chain-of-trust that allows the user to execute mutations that would otherwise have an immedaite impact on other users.

Implementations